summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/opengl/opengl.pro6
-rw-r--r--src/opengl/qopenglwidget.cpp (renamed from src/widgets/kernel/qopenglwidget.cpp)4
-rw-r--r--src/opengl/qopenglwidget.h (renamed from src/widgets/kernel/qopenglwidget.h)6
-rw-r--r--src/widgets/kernel/kernel.pri5
4 files changed, 11 insertions, 10 deletions
diff --git a/src/opengl/opengl.pro b/src/opengl/opengl.pro
index 820e46ed79..eaa10de22a 100644
--- a/src/opengl/opengl.pro
+++ b/src/opengl/opengl.pro
@@ -1,5 +1,6 @@
TARGET = QtOpenGL
QT = core-private gui-private
+qtConfig(widgets): QT += widgets widgets-private
DEFINES += QT_NO_USING_NAMESPACE QT_NO_FOREACH
@@ -23,4 +24,9 @@ SOURCES += \
SOURCES += qopengltimerquery.cpp
}
+qtConfig(widgets) {
+ HEADERS += qopenglwidget.h
+ SOURCES += qopenglwidget.cpp
+}
+
load(qt_module)
diff --git a/src/widgets/kernel/qopenglwidget.h b/src/opengl/qopenglwidget.h
index 9eb4a9ba5a..b331880b5d 100644
--- a/src/widgets/kernel/qopenglwidget.h
+++ b/src/opengl/qopenglwidget.h
@@ -3,7 +3,7 @@
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtWidgets module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -40,7 +40,7 @@
#ifndef QOPENGLWIDGET_H
#define QOPENGLWIDGET_H
-#include <QtWidgets/qtwidgetsglobal.h>
+#include <QtOpenGL/qtopenglglobal.h>
#ifndef QT_NO_OPENGL
@@ -52,7 +52,7 @@ QT_BEGIN_NAMESPACE
class QOpenGLWidgetPrivate;
-class Q_WIDGETS_EXPORT QOpenGLWidget : public QWidget
+class Q_OPENGL_EXPORT QOpenGLWidget : public QWidget
{
Q_OBJECT
Q_DECLARE_PRIVATE(QOpenGLWidget)
diff --git a/src/widgets/kernel/kernel.pri b/src/widgets/kernel/kernel.pri
index 58107973d8..a960280959 100644
--- a/src/widgets/kernel/kernel.pri
+++ b/src/widgets/kernel/kernel.pri
@@ -68,11 +68,6 @@ qtConfig(action) {
kernel/qwidgetaction.cpp
}
-qtConfig(opengl) {
- HEADERS += kernel/qopenglwidget.h
- SOURCES += kernel/qopenglwidget.cpp
-}
-
qtConfig(formlayout) {
HEADERS += kernel/qformlayout.h
SOURCES += kernel/qformlayout.cpp
diff --git a/src/widgets/kernel/qopenglwidget.cpp b/src/opengl/qopenglwidget.cpp
index 90622fd21e..a6c63ae034 100644
--- a/src/widgets/kernel/qopenglwidget.cpp
+++ b/src/opengl/qopenglwidget.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWidgets module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -59,7 +59,7 @@ QT_BEGIN_NAMESPACE
/*!
\class QOpenGLWidget
- \inmodule QtWidgets
+ \inmodule QtOpenGL
\since 5.4
\brief The QOpenGLWidget class is a widget for rendering OpenGL graphics.
@@ -3,7 +3,7 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtWidgets module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$